VERSION 8000; ; 8400
* -----------------------------------------------------------------------------
* @filedoc
* @file DB_FlurstckslinieDatenZeigen.CSX
* @brief Zugrif auf ODBC-Datenbank 
* 
* Dieses Beispielskript stellt eine Verbindung zu einer ODBC-Datenbank her, z.B. CARD/1 Grunderwerbsdatenbank.
* Es werden Flurstckslinien farblich hervorgehoben, die mit einem Sachdatensatz verknpft sind.
*  
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author RM
* @endfiledoc
* -----------------------------------------------------------------------------
*    8300 18.05.09 JH Anpassungen zur 8.3
*    8400 03.02.11 RM Zusammenfassen von ODBC-DB-Verbindung in Funktionen, damit versionsunabhngig
* @history
* -----------------------------------------------------------------------------

* --- Vereinbarungen ----------------------------------------------------------

BILDSCHIRM GRAFIK       | gibt die Meldungen im Arbeitsprotokoll aus

* --- Implizite Deklarationen -------------------------------------------------

!Name_FlstSchicht = "Flurstcke"                 | Name der Flurstcksschicht

* --- Explizite Deklarationen -------------------------------------------------

* Systemobjekt
SYMBOLE /TOPOSYS/ Toposys                        | Symbol fr das System der Topografiedaten

* Topografieojekte
SYMBOLE /TOPOLINE/ Linie                         | Symbol fr die Topografielinie
SYMBOLE /TOPOLINEINDEX/ XLinie                   | Symbol fr das Linienindexobjekt 

* Datenbankobjekte
SYMBOLE /DBCONNECTION/ DataBase                  | Symbol fr Datenbankzugriff
SYMBOLE /DBCOMMAND/ Stmt                         | Symbol fr DB-Anweisung

SYMBOLE * kk                                     | Symbol fr DB-Verbindungsstatus                         

* Ausfhrungen ----------------------------------------------------------------

* Systemobjekte 
Toposys = Project.GetTopoSys()             
DataBase = Project.GetDataBase()

*** Verbindung mit ODBC-Datenbank des akt. Projektes herstellen
WENN GE_DB_connect(DataBase; 1) == 0 DANN STOP |Abbruch, wenn keine Verbindung mglich

*** Schleife zum Auslesen der Linien ber gesetzte Filter

* Linienindexobjekt:  Auswahl der Linien ber Schicht, Kode und Markierung
XLinie = TopoSys.GetLineIndex(!Name_FlstSchicht)                          | liefert das Linienindexobjekt der Schicht
XLinie.SetMarkFilter(1)                                                   | setzt einen Markierfilter
LinMarkAnz = 0 |Anzahl markierter Linien in Schicht
LinFlstAnz = 0 |Anzahl markierter Linien mit Flurstck in Grunderwerbsdatenbank
* Linienobjekt
SOLANGE Linie = XLinie.GetNext() | liest Linien ber gesetzte Filter aus

  LinMarkAnz = LinMarkAnz + 1
  LP_Id = Linie.GetDataLink(1)   | liefert fr die Linie die ID des verknpften Sachdatensatzes
  
  WENN LP_Id > 0 DANN            | Linie hat einen verknpften Sachdatensatz
  
    Linie.Draw(6)                | visualisiert die Linie gelb
    
    * DB-Anweisung fr die Ausfhrung vorbereiten: Abrufen von Datenstzen aus einer Tabelle
    TEXTGEN !SQLSequenz; "SELECT * FROM Flurstueck_CRD WHERE [Flurstueck_CRD].[P_ID]=#;"; LP_Id
    Stmt = DataBase.CreateCommand(!SQLSequenz)                            | View auf Flurstckstabelle mit nur dem Datensatz, der zur Linie gehrt
    * DB-Anweisung SELECT ausfhren
    kk = Stmt.Execute();
    * Datenstze ermitteln
    iostat = Stmt.GetNextRow()                                            | liefert die nchste Datensatzzeile (hier: erste und einzige) 
    WENN iostat == 0 DANN
      MELDUNG FEHLER "Der Datensatz zur aktuellen Linie wurde nicht gefunden"
    SONST
      LinFlstAnz = LinFlstAnz + 1
      !Flurstueck_Nr = Stmt.GetStringByName("Flurstueck_Zaehler")         | liefert Zhler aus DB 
      !Flurstueck_Nenner = Stmt.GetStringByName("Flurstueck_Nenner")      | liefert Nenner aus DB 
      !FlstBemerkung = Stmt.GetStringByName("Bemerkung")                  | liefert Bemerkung aus DB 
      WENN T_LANG(!Flurstueck_Nenner) > 0 DANN !Flurstueck_Nr = !Flurstueck_Nr + "/" + !Flurstueck_Nenner
      TEXTGEN !Meldung; "Die gelbe Linie ist Flurstck # und hat die Flurstcksbemerkung '#'"; !Flurstueck_Nr; !FlstBemerkung
      MELDUNG WEITER; !Meldung; weiter; 1
      WENN weiter == -1 DANN ABBRUCH SOLANGE
    WEITER
    Linie.Draw(4) | visualisiert Linie wieder grn, damit es nur eine aktuelle gelbe gibt
    
  WEITER
  
ENDE SOLANGE

*** Ende Schleife 

MELDE ''
MELDE '##### markierte Linien in Schicht "#" untersucht'; LinMarkAnz; !Name_FlstSchicht
MELDE '##### markierte Linien mit Flurstck in Grunderwerbsdatenbank gefunden'; LinFlstAnz

MELDUNG NEUTRAL "Skript beendet"

STOP

* ------------------------------------------------------------------------------------------------------------

FUNKTION GE_DB_connect: {/DBCONNECTION/}GEDBase; Mode = 1
* Verbindung zur ODBC-Datenbank des Gerunderwerbs im akt. Projekt herstellen
* -> GEDbase: Datenbankobjekt der Klasse DBCONNECTION
* -> Mode: (optional), 0 = keine Meldungen, 1 = Verbindungsmeldung + ggf. Fehlermeldung
* <- ioDB: 1 = Verbindung OK, 0 = keine Verbindung zur Datenbank
ioDB = GEDBase.Connect(!ProjektODBC(); ""; ""; "ODBC")
WENN Mode == 1 DANN MELDE "Verbindungsstatus: # (1=OK, 0=Fehler) Version #"; ioDB; !!DataBase.GetVersion()
WENN ioDB <> 1 & Mode > 0 DANN     | wenn DB nicht ordnungsgem verbunden
  TEXTGEN !Meldung; 'ODBC-Datenbank "#" konnte nicht geffnet werden,\nggf. "Grunderwerb erfassen" starten!'c; !ProjektODBC()
  MELDE !Meldung
  MELDUNG FEHLER !Meldung
WEITER

ZURCK ioDB

ENDE FUNKTION GE_DB_connect
* ------------------------------------------------------------------------------------------------------------
FUNKTION !ProjektODBC:
* liefert ODBC-Namen der Grunderwerbsdatenbank des aktuellen Projekts
  !ODBCName = Project.GetName()
  !ODBCName = !_TEIL(!ODBCName; 1; 27)
  ProjektNamLen = T_LANG(!ODBCName)
  !Textmuster = ""
  SCHLEIFE i = 1; ProjektNamLen
    !Textmuster = !Textmuster + " "
  ENDE SCHLEIFE
  SCHLEIFE i = ProjektNamLen + 1; 27
    !Textmuster = !Textmuster + "_"
  ENDE SCHLEIFE
  !Versionsnr = !_TEIL(!_VERSION; 2; 2) + !_TEIL(!_VERSION; 4; 4) |1.Zeichen = Leerzeichen, 2.= "8", 3.= "."
  !Textmuster = !Textmuster + !Versionsnr
  !ODBCName = !Textmuster & !ODBCName
  ZURCK !ODBCName
ENDE FUNKTION !ProjektODBC
